from coprs import app, db, models
class WebhooksLogic:
    """To retrieve Webhooks related records from backend."""

    @classmethod
    def get_all_webhooks(cls, copr):
        """
        Returns all webhooks received for a copr in newest first order.
        """
        builds = (db.session.query(models.Build)
                .filter(models.Build.copr_id == copr.id))

        webhook_history = []
        if builds:
            for build in builds:
                if build.webhook_history_id is not None:
                    app.logger.info(
                    "Querying webhook_history by ID: '%s' associated with build.",
                        build.webhook_history_id)
                    webhook = (models.WebhookHistory.query
                            .filter_by(id=build.webhook_history_id).one())
                    webhook_history.append(webhook)

        #Remove any duplicates from the webhook history list.
        seen = set()
        webhook_history = [wh for wh in webhook_history if not (wh.id in seen or seen.add(wh.id))]

        return webhook_history
